#include "gtk.h"
/* XPM */
static const char *const xpm_icon_0[] = {
/* columns rows colors chars-per-pixel */
"128 128 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXlXbXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXbXlXkXlXlXlXlXkXzXbXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXvXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXkXcXvXeX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X7XtXnXxXkXlXlXjXbXxXwX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X7XuXmXzXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXxXgXc.i                                                                                               k D.zXxXlXkXcXpXi.9                                                                                               N E.vXzXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXvXe.  O X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X . X   m.bXkXlXzX$.  O X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X .     R.bXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXNX;X4 o X                                                                                               X X y eXxXCX'.- o X                                                                                               . . c kXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                                                                                                   X   6XcXFXK.  @                                                                                                     @ hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                                                                                                   X   6XcXFXJ.  @                                                                                                     O hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                                                                                                   X   6XcXFXJ.  @                                                                                                     O hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                     X O o                                                     . O o               X   6XcXFXJ.  @             .     . X .     .                                                 O o .                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +               .   W lXUX*X  X                                           o   k iXUX2X8   .         X   6XcXFXJ.  @           .   O ;.sXUXdX<.X   .                                       .   y .XUXZXd   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +           . X   e.UXGXUX<X  X                                         .   . A.UXUX8X9   .         X   6XcXFXJ.  @           o   f.UXVXyXSXUXG.  o .                                   .   V ZXUXDXPXf   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +           X   : XX{.f.PX<X  X                                         .   K UXzXZXqX8   .         X   6XcXFXJ.  @         O   C cXDXH   z 4X].w   X                                       q.iX8.qXUXs   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +           .   * P    .UX<X  X                                           & 0XvX8.wXiX6   .         X   6XcXFXJ.  @         O   :.UXe.r o.+.Y - &                                         . M r 0 uXUXa   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                     ;.UX<X  X                                           1.UXz.g nXeX6   .         X   6XcXFXJ.  @       . .   l.UXK.8XUXUXfX]   O                                             b eXUXa   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                 @   *.UX<X  X                                         q GXxX2 b cXeX9   .         X   6XcXFXJ.  @       .   X S.UXFXe.v f.UXwX8   X                                       +   l rXUXa   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                 o   *.UX<X  X                                     X   !.UX,.  x kXqX-   X         X   6XcXFXJ.  @       .     b.UXW.X   - yXVX!   O                                       o   l rXUXa   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                 o   *.UX<X  X                                   .   q GXUXCXmXVXPXJXJXl           X   6XcXFXJ.  @         +   2.UXK.%   & rXCXE   O                                       o   l rXUXa   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                 o   &.PX:X  X                                   .   w eXnXnXMXVXKXFXHXl           X   6XcXFXJ.  @         o   B xXUX| = r.UX4X7   X                                       o   k qXPXa   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                 o   1.UXtX  X                                                 N IXjX:   X         X   6XcXFXJ.  @           o   2.DXUXUXUXlX|   O                                         o   v xXUXf   X             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                 X   U _.z.  .                                         X o +   h U.N.1   .         X   6XcXFXJ.  @             X   H Z.!.b.m   o                                           X   r B._.8   .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                   .       .                                                 .         .           X   6XcXFXJ.  @               o           o                                               .         .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX.X  +                     o # @                                                     X @ @ .             X   6XcXFXJ.  @                 o @ # @ o                                                   . @ # .                 O hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCX X  +                                                                                                   X   6XcXFXJ.  @                                                                                                     o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXjXCXoX  O                                                                                                   .   7XcXDXI.  +                                                                                                     = hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXkXnX7Xb   X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X .   J pXzXMX*Xa   X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X     ) zXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXjXBXT., X                                                                                               O 6 .XmXkXhXVXn.=                                                                                                 + y <XbXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXjXNX:X..c k l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l k b %.7XmXkXlXlXjXBXoX_ z k l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l k M 1.uXnXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXxXAXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXZXzXkXlXlXlXlXkXvXSXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXGXCXlXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXgXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXgXkXlXlXlXlXlXlXkXgXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXdXpXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXuXaXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXZXLXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXAXjXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXvXz./ U T Y Y Y Y Y Y Y Y Y Y Y Y Y T Y ~ a.jXbXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXsXH *                                       % b 8XvXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX5.    o O o o o o o o o o o o o o o o o o o     O.zXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXy   .                                       .   : hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX3   .                                           X hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXdXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXdXfXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXdXdXfXjXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .               . + @ @ O .                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXvXGXPXJXnXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXHXUXHXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXBXKXPXGXcXhXzXlXlXlXlXlXlXlXlXlXjXVX4   .             . X         X .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXMX<Xa.<.r.OXCXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXwXr.X.t.rXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXcX~.6.,.f.2XBXjXlXlXlXlXlXlXlXlXlXjXVX4   .           .     [ s.p./     .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXVX_.f       r S.CXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXb.    6 2XMXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXjX7.&       M oXnXjXlXlXlXlXlXlXlXlXjXVX4   .             # I.KXUXUXDXN.X               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbX9XF   '  X-.  r 3XxXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMX3X0   . k 4XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXAXU.  $ C.+XP   ( SXfXlXlXlXlXlXlXlXlXjXVX4   .             ,.UXiX^ | vXUX_               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXQ.  g -XJXgXj   i.SXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXzX%.  E y r 6XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXXX1.W.BXPXT.  V mXhXkXlXlXlXlXlXlXlXjXVX4   .           . gXCXR     B X.c               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXj.   .gXzXcX,.  ( LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnX.X  F ^.6 y 6XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXcXqX+XK @ 0.AXgXlXlXlXlXlXlXlXlXjXVX4   .           0 UXwX~ 6XKX5XK                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXq.  ;.vXkXxXa.  I JXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXkXv   L.@X, u 1XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXsX6     #.fXcXkXlXlXlXlXlXlXlXlXjXVX4   .       .   B UXJXyX|.@XUXUXv               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXt.  &.lXlXkXt.  T KXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXl.  { UX*X6 s jXCXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXmXjXp.{ u   ,.xXjXkXlXlXlXlXlXlXlXjXVX4   .       .   C IXUX7.    W.UXv.              o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXZXC.  W yXzXbX_   +.JXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXaXe # o.M.;.- 4 9.rXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXwX*XaXSXLX*X  4 ].MXhXlXlXlXlXlXlXlXjXVX4   .           0 UXlXl &   ,.UX~.              o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX|.- $ H.LXOX- $ J.BXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX&X                ).mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXj.4 -.eXZXW.  8 /.NXhXlXlXlXlXlXlXlXjXVX4   .           . tXUXe.    /.UXa.              o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzX;.  8 I e   I zXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXaXY.H.L./.y.; q M.aXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCXR.    M P 3   T lXjXkXlXlXlXlXlXlXlXjXVX4   .             ) UXAXQ.OXUXCXp               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXvXyX9.,   @ $.0XbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXDXGXAXUXoX# e sXVXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX~.V     > ;.8XbXjXlXlXlXlXlXlXlXlXjXVX4   .               [ eXUXUX+XM                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXlXeX0XwXhXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXhXgXjXaX7X9XfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXvXpXqX0XeXkXnXjXlXlXlXlXlXlXlXlXlXjXVX4   .                 ; 2 1 %                   o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXbXmXnXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXnXnXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXnXmXbXxXkXlXlXlXlXlXlXlXlXlXlXjXVX4   .                         .                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                 . . .                     o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .               . . . . . .                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXbXmXnXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXbXmXnXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXnXmXbXzXkXlXlXlXlXlXlXlXlXlXlXjXVX4   .                                           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXzXeX0XeXjXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXcXtX0X0XaXvXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXdXqX0XrXzXvXkXlXlXlXlXlXlXlXlXlXjXVX4   .             - 7 4 3 3 3 ; .               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXvXuXq.<   $ *.qXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXx.w     S  XcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbX@XR     4 p.gXlXkXlXlXlXlXlXlXlXlXjXVX4   .             Z.UXUXUXUXUX-X&               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXxX,.  9 U r   Y xXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXq.  - W m   0 1XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXmX%X5   V E -   r.AXgXlXlXlXlXlXlXlXlXjXVX4   .             Q.PX;X_.].}.9.@               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX X: $ K.IX+X- $ L.NXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX~ c m.JXtXH   E.NXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXP.i o.tXKXv.  A NXhXkXlXlXlXlXlXlXlXjXVX4   .             -XMXu                         o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXZXC.  W yXzXbX_   @.JXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzX4X2XnXLX1Xl   ].BXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXiX;XpXJXNXe.  E ZXgXlXlXlXlXlXlXlXlXjXVX4   .             tXfX{ f.b.Y     .             o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXy.  &.lXlXlXt.  T KXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXbXBX'.D f 8 l.hXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXnXhXo.N ; / :XbXjXlXlXlXlXlXlXlXlXjXVX4   .           o LXUXmXUXUXZX|                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXq.  ;.vXkXxXp.  U JXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbXI.    . $.aXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXdXz     h '.NXhXlXlXlXlXlXlXlXlXjXVX4   .             5.F.@.3 q.UXCX3   .           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXh.   .gXzXcX,.  ( LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXcXjXtX:XB   r.zXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXcXcXpXrXf.  j <XvXjXlXlXlXlXlXlXlXjXVX4   .               .       @XUXS               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXSXW.  g =XHXgXj   y.SXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXiXq.w.8XZXUX,.  W sXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXQ.%./.NXPX8X  < R.VXgXlXlXlXlXlXlXlXjXVX4   .           8 v.1.O   @ %XUXm               o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbX7XA   _ }.=.  w 1XxXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXe   U ].M.w   w.zXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXSXf.  3 m.]._   d 1XvXjXlXlXlXlXlXlXlXjXVX4   .           , GXUXi.q z.UXdX:   .           o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX(.s       e C.CXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX~.s       + I 9XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXwX..O       r V.CXgXlXlXlXlXlXlXlXlXjXVX4   .             { jXUXUXUXgXY                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXMX>Xi.,.e.XXCXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNX;Xd.<.4.C.fXbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnXfXH.5.,.p.$XCXhXlXlXlXlXlXlXlXlXlXjXVX4   .               n 9.f.7.s                   o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXvXHXPXJXmXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXbXGXPXLXAXkXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXZXLXPXHXnXgXlXlXlXlXlXlXlXlXlXlXjXVX4   .             o           o                 o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXdXfXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXfXdXdXgXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXdXdXfXjXlXlXlXlXlXlXlXlXlXlXlXjXVX4   .               o @ # @ o                   o hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVX3   .                                           X hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXu   .                                       .   > hXxXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmX7.    o O o o o o o o o o o o o o o o o o o     +.zXzXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXlXlXzXdXK =                                       % m 9XvXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXMXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXMXzXlXkXxXMXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXMXvXkXlXlXxXbXv.( U T Y Y Y Y Y Y Y Y Y Y Y Y Y T U ^ s.kXbXkXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcX3X-X:X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X:X-XhXlXxXiX*X:X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X;X:X=X0XcXkXlXkXhXCXLXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXPXLXAXjXkXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXjXlXlXlXjXMXG.d.l.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.l.f.pXzXmX,Xi.x.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.k.z.p.'.BXjXlXlXlXgXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXdXgXkXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXHXFXMXkXlXlXlXxX0X5X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X5XjXlXxXsX4X7X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X4XyXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXx j l k k k k k k k k k k k k k k k k k k l j G M.mXlXlXlXlXbXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXzXlXlXxXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX                                                @ ^ vXjXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX+   X X X X X X X X X X X X X X X X X X X X X X   # x.CXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   ~ LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   U PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                           O # # O             o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXsXfXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXdXdXfXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXdXdXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                         X         .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXlXkXxXHXIXHXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXZXLXLXSXxXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXSXIXLXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                       o   ^ ).`.}   o         o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXjXmX7X#.H &.qXbXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXbXpXl.) ( w.7XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnXzXu.K ! 3XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                     .   = 9XUXUXc.  O         o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXkXnXs.    9 2XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXrX_         n ,XcXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX2XI       @XVXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                     +   f.UXLXKXp.  O         o   Y PXdXlXlXlXlXlXlXlXlXlXlXkXMX-X,   X h 4XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXFXn.  i |.<Xv   &.GXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXs.  I p . *XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                   O   n bXuXH.PXd.  O         o   Y PXdXlXlXlXlXlXlXlXlXlXlXxXlX`   ] p e 6XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXZ.s G.mXBXm.  I LXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXlXB.A.:Xy   =XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                 .     I.UXT d.UXs.  O         o   Y PXdXlXlXlXlXlXlXlXlXlXlXnX/.  T ].3 u 6XmXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXBXvXlXvX[   <.GXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXSXOXu   =XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                 O   _ UX|.$ l.UXh.  o         o   Y PXdXlXlXlXlXlXlXlXlXlXzXdXp   ^.OX< u <XnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXhXMXc.  p 1XxXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXMXOXu   =XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo               X   6 2XSXe   s.UX7.  +         o   Y PXdXlXlXlXlXlXlXlXlXkXNXw.  =.UX=X6 s lXCXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXnXz.  1 ^.VXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNXOXu   =XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo               X   +.UX6XN.f.1XUX5Xo.  X       o   Y PXdXlXlXlXlXlXlXlXkXlXtX8 + W 2.) & < } 7XcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXvXp.  - R.MXsXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNXOXu   =XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                   f.UXUXUXUXUXJXUXaX  O .     o   Y PXdXlXlXlXlXlXlXlXkXcX*X                _.mXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXe.  0 XXUXVXVXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNXOXu   =XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                   5 M x z a !.UXH.4 X .       o   Y PXdXlXlXlXlXlXlXlXlXlXfXOX X.X:Xm.= q Q.jXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXDXm.    = x g e ` dXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNXOXy   *XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                             b.UXw.  O         o   Y PXdXlXlXlXlXlXlXlXlXlXxXVXZXNXIXXX2 g iXBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXHXw.  *         l aXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXNX+Xa X =XBXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                   . X X X X o O o .           o   Y PXdXlXlXlXlXlXlXlXlXlXlXjXjXjXjXjXhXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXhXhXjXkXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXxXxXxXxXxXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   Y PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                               o   R PXdXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhXo                                             . X X 1.FXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX+   X X X X X X X X X X X X X X X X X X X X X .   a 0XzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXxXhX                                              %  .>XnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlX6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X6X9XgXMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_1[] = {
/* columns rows colors chars-per-pixel */
"96 96 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXlXlXlXlXkXjXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXkXlXlXlXlXlX",
"lXlXlXlXkXzXNXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXCXMXlXlXlXkXxXBXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXZXCXmXkXlXlXlXlX",
"lXlXlXkXxXzXv.B j l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l j F L.bXlXjXvXdXr.b j l k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k k l j T '.MXkXlXlXlX",
"lXlXlXkXmX4.                                                                                v.mXjXzX_                                                                               + !.mXkXlXlX",
"lXlXkXbX9X:   o X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X o   i hXVX.X  . o X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X O   H CXhXlXlX",
"lXlXkXnX4X  .               . o X                                         . o X         .   : fXAX).  O             . X X .                                       . X X           X   j ZXhXlXlX",
"lXlXkXnX4X                o       .                                     .               .   , fXAX_.  o           X         X                                   X                 X   l ZXhXlXlX",
"lXlXkXnX4X              .   = b t                                     .   3 v r         .   , fXAX).  O         X   * f p .   X                               X     k h o         X   k ZXhXlXlX",
"lXlXkXnX4X            .   V 0XUX%X  o                               .   o ;XUX}.        .   > fXAX).  O       o   x 4XUXUX`.5   X                           .   8 /.UXFX2   .     X   k ZXhXlXlX",
"lXlXkXnX4X          .   $ 3X4XjX@X  X                               O   >.UXIX(.        .   > fXAX).  O     .   $ 2XHXH ..UXs.  X                           X   V.zX>XNX,   .     X   k ZXhXlXlX",
"lXlXkXnX4X          .   > P 8 sX&X  X                             X   0 BXE.<X.X        .   > fXAX).  O     o   C UXO.x | ! 8 X                               . I 3 P.GX>   .     X   k ZXhXlXlX",
"lXlXkXnX4X                  5 jX%X  X                             X   U.SXs 8XoX        .   > fXAX).  O     X   X.UX|.aXUXnXN   o                             .     /.DX>   .     X   k ZXhXlXlX",
"lXlXkXnX4X              X   6 hX%X  X                           X   G UXQ   eX).  X     .   > fXAX).  O     X   %.UX[.@ l UX`.                                  X   ~.FX>   .     X   k ZXhXlXlX",
"lXlXkXnX4X              X   6 hX%X  X                         . X   %XUXQ.Y.MXNX1.  X   .   > fXAX).  O     o   T UX$.    5X1X+   .                                 ~.FX>   .     X   k ZXhXlXlX",
"lXlXkXnX4X              X   6 dX@X  X                         .   o P.sXgXvXDXUXI.  X   .   > fXAX).  O     X   4 vXhXg &.UXx.  X                                   Q.ZX>   .     X   k ZXhXlXlX",
"lXlXkXnX4X              X   8 VX3X  o                                       cXoX  .     .   > fXAX).  O       o   U gXUXUX_.3   X                                   }.UX,   .     X   k ZXhXlXlX",
"lXlXkXnX4X                  + x d   .                               X o X @ z s .       .   , fXAX).  O         .   1 v h o   X                                     i n o         X   k ZXhXlXlX",
"lXlXkXnX4X                        .                                                     .   , fXAX_.  o           o         X                                                     X   l ZXhXlXlX",
"lXlXkXnX4X  .                 X X                                           X X         .   : fXAX).  O             X o X .                                         X o           X   j ZXhXlXlX",
"lXlXkXbX9X;   X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X o   u hXVX X  X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X X O   G CXhXlXlX",
"lXlXlXkXnX1.                                                                                z.mXjXlX(                                                                               O E.mXjXlXlX",
"lXlXlXkXxXlXz.b a d s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s d a C G.bXlXjXvXaXq.l a d s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s s d a L (.mXkXlXlXlX",
"lXlXlXlXkXzXNXBXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXMXlXlXlXkXxXNXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXVXBXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXmXnXkXlXlXlXlX",
"lXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXgXjXCXDXDXDXDXDXDXDXDXDXDXDXDXDXDXCXkXjXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXgXI.M.N.N.N.N.N.N.N.N.N.N.N.N.M.Y.jXnXkXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvX8XD                                 J qXcXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXo.  o + + + + + + + + + + + + + + o   %.VXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   o                             o   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXhXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXhXhXkXlXlXlXlXlXlXlXlXjXVXs   X           . o O o .         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXlXBXFXFXNXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXDXBXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXZXHXDXmXlXlXlXlXlXlXlXlXjXVXs   X         .           .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXkXzXzXb.v b m.cXzXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXMX9.s >.cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX8X#.a H /.nXkXlXlXlXlXlXlXjXVXs   X       .   M ].9Xg.*   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXMXt.  v l   y.VXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXBX|.    H vXlXlXlXlXlXlXlXlXlXlXlXlXlXkXvXwXt   Y 7 + ].BXhXlXlXlXlXlXjXVXs   X     .   v IXzXOXUX<Xo   .   X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXrX= z xXnXa 6 9XbXjXlXlXlXlXlXlXlXlXlXlXlXlXkXlXzXZ 6 t K bXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX,X^ Y.UX X  y.DXhXlXlXlXlXlXjXVXs   X     o   [.mXq   { u.5   .   X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXmXXX  w.mXmX5.  XXVXjXlXlXlXlXlXlXlXlXlXlXlXlXjXCXn.  H.x S bXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnXiXR.) y XXNXjXlXlXlXlXlXjXVXs   X   .   X nX+Xx.GX3XB   X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXjXMX^.  d.MXcXp.  ].CXjXlXlXlXlXlXlXlXlXlXlXlXkXvXeX-  .bXi K CXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNX).    E pXcXkXlXlXlXlXlXjXVXs   X   .   6 gXUXN.O.NXbX2   .   X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXmX+X  7.MXBX,.  oXVXjXlXlXlXlXlXlXlXlXlXlXlXhXZX%.  T.=Xq m 0XzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXhXkXeXL.  @.bXkXlXlXlXlXlXjXVXs   X   .   % vXqX+   3.UXT   O   X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXvXuX2 t pXdX7 e eXvXkXlXlXlXlXlXlXlXlXlXlXkXlXkXs       O   b VXhXlXlXlXlXlXlXlXlXlXlXlXjXNX].j V.UX,X  G kXzXlXlXlXlXlXjXVXs   X     X   $XAXp   L.UXb   o   X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXMXx.  4 2   c.VXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlX#X/.}.E.% u :XxXkXlXlXlXlXlXlXlXlXlXlXlXjXbX3Xq   t %   F.NXjXlXlXlXlXlXjXVXs   X     X   Z KXnX0XUXP.  .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXbXT./ ( R.nXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBXZXSXcX%.u.ZXkXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX0X7.U  .`.mXlXlXlXlXlXlXlXjXVXs   X       .   x F.).=.X   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXNXKXKXNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXhXkXFXAXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXDXLXJXMXkXlXlXlXlXlXlXlXjXVXs   X         X           .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXfXgXjXlXlXlXlXlXlXlXlXjXVXs   X           X + + o           X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXVXs   X                             X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXhXkXlXlXlXlXlXlXlXlXjXVXs   X         X O O O O X         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXbXDXSXvXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXAXFXNXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXFXAXxXkXlXlXlXlXlXlXlXjXVXs   X       .             .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXjXMX8XL.P.9XNXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXaXE.F.+XnXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXmXOXD.W.aXnXkXlXlXlXlXlXlXjXVXs   X     .   d [ ` ` [ h   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXMX}.w     y |.NXhXlXlXlXlXlXlXlXlXlXlXlXlXkXvX;Xz     + h.nXkXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlX2.      K 0XvXkXlXlXlXlXlXjXVXs   X     X   n.UXUXUXUXz.  o     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXxXhXv   {.[.  V hXzXkXlXlXlXlXlXlXlXlXlXlXlXhXDX3.# G.rXc X pXxXlXlXlXlXlXlXlXlXlXlXlXlXjXMX-X: ( aXk.  l.SXhXlXlXlXlXlXjXVXs   X     X   U.qX=   O %         X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXmX:X  &.VXDX .  %XNXjXlXlXlXlXlXlXlXlXlXlXlXkXcX3X,XAXbXH , sXxXlXlXlXlXlXlXlXlXlXlXlXlXlXxXaX$XhXIXF.  N.AXhXlXlXlXlXlXjXVXs   X     X   =X4X@.c.J   .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXjXMX(.  d.MXvXi.  [.CXjXlXlXlXlXlXlXlXlXlXlXlXlXkXzXZX&.  - R.VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXCX|.>    .lXcXkXlXlXlXlXlXjXVXs   X     X   $XJX4XVXUXo.  X     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXMX'.  i.nXvXe.  }.VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXnXCXK.O.0 v 0XcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXcXZX4X1.J $ D.mXjXlXlXlXlXlXjXVXs   X     .   5 M   $ sXiX  . .   X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXkXnX5X  ~ VXFXP @ >XMXjXlXlXlXlXlXlXlXlXlXlXlXlXxXP.F.ZXUXu.  V.CXhXlXlXlXlXlXlXlXlXlXlXlXkXvX>Xj.7XUXhX  Z kXzXlXlXlXlXlXjXVXs   X       @ ..C     |.nXo   .   X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXcX/   0.7.  ' bXkXkXlXlXlXlXlXlXlXlXlXlXlXhXAX[   @.b.e   oXnXkXlXlXlXlXlXlXlXlXlXlXlXjXNX}.  f m.}   ;.mXkXlXlXlXlXlXjXVXs   X     .   4XUXO.8.UXJ.  o     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXjXbX8X/     _ 0XnXjXlXlXlXlXlXlXlXlXlXlXlXlXkXcXqX} X   y A.mXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXB.0   + O.tXvXkXlXlXlXlXlXjXVXs   X     .   p .XUXUXL.,   .     X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXbXxXtXtXxXbXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXcXyXrXdXNXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXmXsXrXyXvXvXkXlXlXlXlXlXlXjXVXs   X       .   . : ;     .       X   k ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXlXbXbXlXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXvXbXxXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXbXvXkXkXlXlXlXlXlXlXlXjXVXd   X         X         X         X   l ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXjXVXa   X           . . .             X   j ZXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBXP   O O O O O O O O O O O O O O O O   R CXhXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXlXlXlXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXkXnX{.,                                 2 .XnXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXmXlXlXxXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXMXcXkXkXMX*X@.Y R T T T T T T T T T T R Y $.-XMXkXlXlXlX",
"lXlXlXjXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXhXlXlXkXvX&X/.'.`.`.`.`.`.`.`.`.`.`.`.`.`.`.`._.{.kXcXtX/.'.`.`.`.`.`.`.`.`.`.`.`.`.`.`.`.'.^.9XvXkXkXbXDXJXHXHXHXHXHXHXHXHXHXHXHXHXJXDXbXkXlXlXlXlX",
"lXlXjXVXPXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXKXAXlXkXkXnX.XK.T.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.I.W.kXvXwXK.T.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.T.J.4XbXkXlXkXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXkXlXlXlXlXlX",
"lXhXVX!.+.1.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.,.C.zXcXkXlXvXmXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXlXlXzXmXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXmXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXPX;.                                      Q gXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX8.  & + + + + + + + + + + + + + + + + .   b.SXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                                 @   :.KXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                 .               +   ,.KXfXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXkXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +               .                 +   ,.KXfXlXlXlXlXlXlXlXlXlXlXvXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXnXmXnXnXnXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXMXcXzXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +             X   s yXcXR   o     +   ,.KXfXlXlXlXlXlXlXlXlXjXmX..@ [ cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX[.m + k Y.bXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXkXs.: a eXvXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +             X   E.UXUX`   O     +   ,.KXfXlXlXlXlXlXlXlXhXCXR.    P vXlXlXlXlXlXlXlXlXlXlXlXlXlXjXmX,XO 6 q.r X OXNXhXlXlXlXlXlXlXlXlXlXlXlXlXlXjXBX6.  2 & qXbXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +           o   / KX'.CX'   O     +   ,.KXfXlXlXlXlXlXlXkXxXsXd f s H bXlXlXlXlXlXlXlXlXlXlXlXlXlXjXNX|.h (.UXW.  n.GXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXs.Q.` # eXbXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +         X   # gX{.( UX]   o     +   ,.KXfXlXlXlXlXlXlXjXZXe.  ^.k S cXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXmXzXVX=.  {.VXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXBXE $ eXbXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +         X   t.UX* K UXI   +     +   ,.KXfXlXlXlXlXlXkXnX,Xo 9.SXi P FXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXVXz.  ;.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXzXE $ eXbXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +       .   w HX=XA z.IXx.*   .   +   ,.KXfXlXlXlXlXlXjXVX)   z.K.7 d .XcXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXBXd.  | bXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXE $ eXbXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +       X   J UXUXUXUXDXUX(   o   +   ,.KXfXlXlXlXlXkXlXjXv       +   m VXhXlXlXlXlXlXlXlXlXlXlXlXlXkXvXa.  o.NXbXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxX~ - rXvXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +           + 7 9 + 6.UX-.  o     +   ,.KXfXlXlXlXlXlXlXlXwX3XeX-X& j sXlXlXlXlXlXlXlXlXlXlXlXlXlXhXCX(.    . #   8.BXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXcXS   wXbXkXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                   g y.u   X     +   ,.KXfXlXlXlXlXlXlXlXbXnXMXkXf.A.mXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnX>X<.q.2.3.=./.bXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXF.w.sXxXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +             . . o       X       +   ,.KXfXlXlXlXlXlXlXlXkXkXkXlXGXSXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXPXJXKXLXPXVXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXAXJXzXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                   X @ X         +   >.KXfXlXlXlXlXlXlXlXlXlXlXlXgXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXfXfXfXfXfXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                                 @   3.JXfXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX6.  +                               .   $ }.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXfXKX4.  X                                 g K.MXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXkXxXyX2X5X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4X4XiXBXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXkXcXmXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXnXcXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_2[] = {
/* columns rows colors chars-per-pixel */
"88 88 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXjXgXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXhXlXlXlXlXlXjXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXhXlXlXlXlXlX",
"lXlXlXlXlXjXmXHXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXAXlXkXlXlXjXBXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXVXkXlXlXlXlX",
"lXlXlXlXkXNXOX3.-.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.-.m.jXcXkXlXmX!.>.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.;.:.I.bXzXlXlXlX",
"lXlXlXjXNXI.%                                                                       ! hXjXmXi.                                                                        2.nXkXlXlX",
"lXlXlXkXbXx   @ + O + + + + + + + + + + + + + + + + + + + + + + + + + + + + + O + X   U.GX8X,   + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + + +   @ >XMXjXlX",
"lXlXlXlXcX7   .           . + O                                     X + O         +   M.IX,X  .           . O + X                                   . O + .         o   +XBXjXlX",
"lXlXlXlXcX9   .         X                                         X               O   B.PX<X            X         X                               .         .       X   @XBXjXlX",
"lXlXlXlXcX8   .       X   , 2. .                                X   r 5./         O   N.IX<X          .   : #.2.u   X                           .     O.,.-   .     X   @XBXjXlX",
"lXlXlXlXcX8   .     X   l pXUXzX                              . .   `.UX<X        O   N.IX<X        .   2 9XUXFXUXW   o                       .   , @XUXUXu   X     X   @XBXjXlX",
"lXlXlXlXcX8   .     X   ;.B./.uX                              o   ' GXaXOX        O   N.IX<X        O   v.GXt o D.=.  .                       X   J Y.x.GXe   X     X   @XBXjXlX",
"lXlXlXlXcX8   .         &   Q.fX                            .   $ nXm.P.2X        O   N.IX<X        X   9X$Xz.zXS.-   .                           *   2.UXw   X     X   @XBXjXlX",
"lXlXlXlXcX8   .             ).dX                            o   k.gX  R.=X  .     O   N.IX<X      .   $ 5XUXw.>.UXM.  X                           .   w.UXe   X     X   @XBXjXlX",
"lXlXlXlXcX8   .         .   (.dX                          X   i UX_.U 3XfXC   .   O   N.IX<X      . .   9X6X    |.6X.   .                         o   0.UXw   X     X   @XBXjXlX",
"lXlXlXlXcX8   .         .   ^.pX                          X   F VXCXUXHXUX/.  o   O   N.IX<X        O   c.UXF d LXU.  .                           o   8.PXw   X     X   @XBXjXlX",
"lXlXlXlXcX8   .         .    XmX                                X .   &X8X        O   N.IX<X        .   > |.UXUX<Xt   X                           o   u.UXr   X     X   @XBXjXlX",
"lXlXlXlXcX9   .             p x                                       s g         O   N.PX<X          .   . x b $   X                             .   8 N @         X   @XBXjXlX",
"lXlXlXlXcX9   .                                                     .             O   B.PX<X            .         X                                 .               X   @XBXjXlX",
"lXlXlXlXcX7   X             X X                                       X X         @   M.IX,X  X           . o o .                                     . o           O   +XBXjXlX",
"lXlXlXkXmXJ   + O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O +     _.AXtXr   + O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O O +   1 6XnXkXlX",
"lXlXlXjXmX#Xg                                                                     @ 8.bXgXMXU.6                                                                     , V.NXjXlXlX",
"lXlXlXlXjXMXtXY.J.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.J.OXMXzXlXkXBX3XL.J.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.K.J.H.H.H.H.H.H.H.H.H.H.H.H.H.H.:XBXkXlXlXlX",
"lXlXlXlXlXjXcXSXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXNXjXlXlXlXjXbXSXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXSXAXLXIXIXIXIXIXIXIXIXIXIXIXIXIXNXfXlXlXlXlX",
"lXlXlXlXlXlXkXhXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXjXlXlXlXlXlXjXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXkXcX<X&X*X*X*X*X*X*X*X*X*X*X*X*XiXNXjXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXzXhX*.&                           k `.MXjXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXa.    . . . . . . . . . . . . o   t rXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXgXGXU   O           . . .           O   +XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXxXvXlXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXcXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXvXcXkXkXlXlXlXlXlXlXgXGXY   O         X       X         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXMXfXuXxXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXrXuXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXnXiXpXbXcXkXlXlXlXlXlXgXGXY   O       X   . - X   .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXjXmXb.3   G <XmXjXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZXy.  J zXlXlXlXlXlXlXlXlXlXlXlXlXkXcX0X/ . X %.dXxXkXlXlXlXlXgXGXU   O     X   M 8XUXaXY   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXjXBX'.  / T.@ S xXlXkXlXlXlXlXlXlXlXlXlXlXlXjXnX>X;   Z zXlXlXlXlXlXlXlXlXlXlXlXlXhXSX=.. S.h.  x.SXhXlXlXlXlXgXGXU   O   X   > jX4Xv '.yX:   .   X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXGX@.+ 7XUX0.  &XNXjXlXlXlXlXlXlXlXlXlXlXlXjXVXL c Y v xXlXlXlXlXlXlXlXlXlXlXlXlXkXvX$X*XUX-X  h.SXhXlXlXlXlXgXGXU   O   o   ( UXY X.5.v O       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXkXNXT 9 fXmXG.  '.CXhXlXlXlXlXlXlXlXlXlXlXhXZXP.   X) z cXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXzXS   L gXcXkXlXlXlXlXgXGXU   O   o   2.UX#X;XUX).  .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXjXCX! 4 sXCXC.  }.CXjXlXlXlXlXlXlXlXlXlXkXxXdXi _ IXP v bXlXlXlXlXlXlXlXlXlXlXlXlXlXkXnXnXK.,.& s.MXjXlXlXlXlXgXGXU   O   o   <.UXo.  ,.UXB   o   X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXGXe.  `.UXQ % 6XnXjXlXlXlXlXlXlXlXlXlXjXBXW.    o $   W VXjXlXlXlXlXlXlXlXlXlXlXkXbXq.w.UXJX- m cXlXlXlXlXlXgXGXU   O   o   T UX_   ;.UXM   o   X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXkXcX9Xe - n   5.BXjXlXlXlXlXlXlXlXlXlXlXkXcX8XZ.N.Z.q = ).vXkXlXlXlXlXlXlXlXlXlXlXhXCX,.  j i   x.BXjXlXlXlXlXgXGXU   O   .   + @XJX'.UX[.  .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXjXmX4X=.R N.cXzXlXlXlXlXlXlXlXlXlXlXlXlXkXvXFXFXPXa.q.AXkXlXlXlXlXlXlXlXlXlXlXlXlXlXbXF.! ( Y.bXlXlXlXlXlXlXgXGXU   O     .   - t.'.9.%   .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXvXGXPXCXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXgXgXfXZXAXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXVXLXKXBXkXlXlXlXlXlXlXgXGXU   O       .           .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXgXgXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXgXgXjXlXlXlXlXlXlXlXgXGXU   O         . O + O .         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXU   O                           X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXkXgXgXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXhXgXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXgXjXlXlXlXlXlXlXlXgXGXU   O       . O + + + o         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXkXvXGXPXCXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXxXDXPXFXxXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXBXLXKXMXkXlXlXlXlXlXlXgXGXU   O     .             .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXjXnX5X-.R V.cXzXlXlXlXlXlXlXlXlXlXlXlXlXkXvXsXr.P 4.eXvXkXlXlXlXlXlXlXlXlXlXlXlXlXkXmXW.~ _ `.mXkXlXlXlXlXlXgXGXU   O   .   < v.'.].OXo.  X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXkXcXqXr ; m   7.BXjXlXlXlXlXlXlXlXlXlXlXkXzXhXm   D # Z kXzXlXlXlXlXlXlXlXlXlXlXlXjXVXk.  z p @ _.BXhXlXlXlXlXgXGXU   O   o   f IXuX(.*X&.  X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXGXr.  '.UXQ & 7XnXjXlXlXlXlXlXlXlXlXlXkXvXtX@.`.UXw.  9XvXkXlXlXlXlXlXlXlXlXlXlXjXBXz.8.UXfX  6.GXgXlXlXlXlXgXGXU   O   o   m BXz       X       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXjXCX! 4 sXCXC.  }.CXjXlXlXlXlXlXlXlXlXlXlXlXkXCX3X:.a &.vXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbXnXv.F x ;XmXjXlXlXlXlXgXGXU   O   O   T UX5XUXuXl   X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXkXNXT 9 fXmXG.  '.CXhXlXlXlXlXlXlXlXlXlXlXlXlXFX'.0 # o.jXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXzXR $ a #XnXjXlXlXlXlXgXGXU   O   .   2 9.' c cX;X  X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXgXGX@.+ 7XUX0.  &XNXjXlXlXlXlXlXlXlXlXlXlXxXtX(.dXUXH.  F.VXhXlXlXlXlXlXlXlXlXlXlXlXlX X=XUXBX& D vXlXlXlXlXlXgXGXU   O   .   0 b     v.ZXo   .   X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXjXBX_.  ^ U.@ Z zXlXkXlXlXlXlXlXlXlXlXlXkXnX,XX F ~.E   _.MXjXlXlXlXlXlXlXlXlXlXlXjXCXR + N.l.  } mXkXlXlXlXlXgXGXU   O   o   Q UXu.I GX'.  X     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXjXmXc.2   D ,XmXjXlXlXlXlXlXlXlXlXlXlXlXkXvXV.9   4 j.bXkXlXlXlXlXlXlXlXlXlXlXlXkXbX>XK   . ^ 9XbXjXlXlXlXlXgXGXU   O   .   X y.AXUX[.9   .     X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXMXfXuXxXnXjXlXlXlXlXlXlXlXlXlXlXlXlXlXzXNXhXuXfXNXzXlXlXlXlXlXlXlXlXlXlXlXlXlXkXmXcXiXpXbXbXkXlXlXlXlXlXgXGXY   O     .     $ =     .       X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXjXxXvXlXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXxXvXxXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXlXvXcXkXkXlXlXlXlXlXlXgXGXY   O       . X       X         X   @XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXgXGXU   O           . .             O   +XBXjXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXlXlXlXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXkXhXCXs.    X . . . . . . . . . . . o   y rXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXxXbXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXbXxXlXzXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXvXbXcXkXzXhX-.*                           l '.MXjXlXlX",
"lXlXlXkXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXhXkXlXlXxXpX9X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XdXxXjX0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X0X9XrXzXkXcXmX4X;X:X;X;X;X;X;X;X;X;X;X;X;XaXNXjXlXlXlX",
"lXlXkXcXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXDXSXvXjXkXmX@Xb.Z.C.C.C.C.C.C.C.C.C.C.C.C.C.Z.b.,XMXiXV.C.C.C.C.C.C.C.C.C.C.C.C.C.C.Z.m.W.bXkXkXjXnXMXMXMXMXMXMXMXMXMXMXMXMXMXxXjXlXlXlXlX",
"lXkXcXyXG.K.K.K.K.K.K.K.K.K.K.K.K.K.K.J.I.qXNXjXzXjXfXgXfXfXfXfXfXfXfXfXfXfXfXfXfXgXfXjXlXkXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXgXfXgXlXlXlXlXkXjXjXjXjXjXjXjXjXjXjXjXjXjXkXlXlXlXlXlX",
"lXjXVXoX                                  u }.MXjXzXxXzXxXxXxXxXxXxXxXxXxXxXxXxXxXzXxXzXlXlXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXxXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX#X  @ O O O O O O O O O O O O O O +   M xXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X                 X o .       .   : gXxXlXlXlXlXlXlXlXlXlXkXhXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXhXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X               .       .     .   , gXzXlXlXlXlXlXlXlXlXkXcXCXNXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXcXCXBXlXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXjXBXCXzXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X             .   r C 3   .   .   , gXzXlXlXlXlXlXlXlXkXcXuX[.&XlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXMXyX}.#XlXvXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXcXBX#X{.dXxXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           .   2 cXUX*.  O   .   , gXzXlXlXlXlXlXlXlXjXCX$.  m zXlXlXlXlXlXlXlXlXlXlXlXlXjXnXOXi     ) aXxXkXlXlXlXlXlXlXlXlXlXlXlXlXzXgX%.    >XMXjXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           o   B.UXAX$.  o   .   , gXzXlXlXlXlXlXlXjXNX[.@ % S zXlXlXlXlXlXlXlXlXlXlXlXlXhXSXH > 4XM.  Z.DXgXlXlXlXlXlXlXlXlXlXlXlXjXNX^.j Q $ ,XmXjXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X         o   Z LX9.kX:.  o   .   , gXzXlXlXlXlXlXlXlXbXg Y ^ x zXlXlXlXlXlXlXlXlXlXlXlXlXlXxX|.$XKX%X  N.FXgXlXlXlXlXlXlXlXlXlXlXlXlXcX7XjXd.  1XmXjXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X             6XY.4 SX@.  O   .   , gXzXlXlXlXlXlXhXSXj.+ 0X/ c MXlXlXlXlXlXlXlXlXlXlXlXlXlXlXMXZXdXh p iXxXkXlXlXlXlXlXlXlXlXlXlXlXlXkXzXDX0.  1XmXjXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X       o   &.UXG B FXe.  X   .   , gXzXlXlXlXlXkXvX0X, ' aXA g wXxXkXlXlXlXlXlXlXlXlXlXlXlXjXvXyXx : :XMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXVXw.  1XmXjXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X       X   ~.UXUXUXFXUXQ   o .   , gXzXlXlXlXlXjXBXE.      O   H CXhXlXlXlXlXlXlXlXlXlXlXkXcXeXn 8 7XKXxXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXCXr.O 1XmXjXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           7 l e ( UXl.  .   .   , gXzXlXlXlXlXlXzXpX%X#X>Xd 6 6XxXkXlXlXlXlXlXlXlXlXlXlXhXDXD   O 8   w.VXjXlXlXlXlXlXlXlXlXlXlXlXlXlXhXZX2.  >XMXjXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X                 * ;.p   X   .   , gXzXlXlXlXlXlXlXxXBXNXZXP.F.MXlXlXlXlXlXlXlXlXlXlXlXlXkXnXF.u.i.w.5.).bXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX|.s.yXcXkXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X           . X o       X     .   , gXzXlXlXlXlXlXlXlXjXjXhXZXAXjXlXlXlXlXlXlXlXlXlXlXlXlXlXkXSXJXHXKXLXVXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXNXHXxXkXlXlXlXlXlXlXlXlXlX",
"lXjXBX@X  X                 . + X       .   : gXxXlXlXlXlXlXlXlXlXlXlXhXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXhXfXgXgXfXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXgXkXlXlXlXlXlXlXlXlXlXlX",
"lXjXBX#X  # + + + + + + + + + + + + O + +   a lXzXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXjXVXoX                                  @ S.NXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXkXbX6X%.:.;.;.;.;.;.;.;.;.;.;.;.;.;.-.2. XNXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXkXvXKXJXJXJXJXJXJXJXJXJXJXJXJXJXJXJXHXMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXfXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_3[] = {
/* columns rows colors chars-per-pixel */
"64 64 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXkXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXhXlXlXlXhXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXgXkXlXlXlXlX",
"lXlXlXlXkXbXFXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXHXCXkXlXlXZXHXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXGXHXFXcXkXlXlXlX",
"lXlXlXjXnX2X2.$.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.#.K.bXlXxXB.@.*.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.&.*.#.9.wXbXkXlXlX",
"lXlXkXxXsXg                                                   Z.UXp.                                                  D cXlXlXlX",
"lXlXjXMX;X  O O O O @   X O O O O O O O O O O O + o   O O $   X.UXL   $ O O @   o @ O O O O O O O O O O + +   O O +   % rXvXkXlX",
"lXlXjXMX>X            - @                           ; .   O   #.UXT   o       1 o   X                 .     > .   .   ; tXvXkXlX",
"lXlXjXMX:X    . .   9.PXX.  O                 o   /.jX=   +   @.UXY   O X   u.0X=Xn   X             .   < {.cX7   X   - tXvXkXlX",
"lXlXjXMX:X    .   ; %.3X2.  O               O   ( bX8X5   +   @.UXY   @   b dX~ z.G   X             X   l u.pXt   o   - tXvXkXlX",
"lXlXjXMX:X        X   {.4.  O             .   % XXI @X&   +   @.UXY   #   | vXv.qXQ   X               X   ; aXr   o   - tXvXkXlX",
"lXlXjXMX:X        X    X1.  O             O   p.DXg.VX{   #   @.UXY   @   / NX  a. X  o               .   w iXe   o   - tXvXkXlX",
"lXlXjXMX:X        X   :Xq.  O             X   G q.A.UX|   #   @.UXY   O   = ;X'.yX`   o               X   w NXy   o   - tXvXkXlX",
"lXlXjXMX>X        .   D p   .               .       H     O   #.UXT   o X   , %.V   .                 .   % R *   .   ; tXvXkXlX",
"lXlXjXMX-X  X X X X o     o . X X X X X X X . O # o   o X @   o.UXP   + . o       O X X X X X X X X X X X       X X   = rXvXkXlX",
"lXlXkXbX9X&                                                   0.UXX.                                                  0 fXxXkXlX",
"lXlXlXjXmXF.s w e e e e e e e e e e e e e e e e e e e e e 0 | uXnX8XQ 0 r e e e e e e e e e e e q 9 9 9 9 9 9 9 0 8 h ~.MXjXlXlX",
"lXlXlXlXkXNXvXlXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXzXlXBXvXjXbXNXlXzXzXzXzXzXzXzXzXzXzXzXkXnXDXDXDXDXDXDXDXDXDXGXMXkXlXlXlX",
"lXlXlXlXlXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXkXlXkXjXlXlXlXlXlXlXlXlXlXlXlXkXMX4XD.D.D.D.D.D.D.F.A.W.kXxXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXnX*X5                     O.nXkXlXlX",
"lXlXlXlXlXlXlXlXlXkXhXjXjXlXlXlXlXlXlXlXlXlXlXlXlXjXjXlXlXlXlXlXlXlXlXlXlXlXjXjXhXkXlXlXlXgXGXi.  $ O o + @ @ + o +   & yXcXkXlX",
"lXlXlXlXlXlXlXlXkXcXZXCXBXkXlXlXlXlXlXlXlXlXlXlXkXBXBXlXlXlXlXlXlXlXlXlXlXzXAXVXCXcXkXlXlXgXGXi.  O   .         . .   ; tXvXkXlX",
"lXlXlXlXlXlXlXkXcXiX| l Z.NXjXlXlXlXlXlXlXlXlXhXAX5.Z pXcXkXlXlXlXlXlXlXlXlXw.g $.aXxXkXlXgXGXi.  O X   z oX XN   o   - tXvXkXlX",
"lXlXlXlXlXlXlXhXFX@.V R.: %XMXjXlXlXlXlXlXlXjXBXXX# 6 9XbXkXlXlXlXlXlXkXmX:XY ;Xy g.GXhXlXgXGXi.  +     2Xr.p.9.  o   - tXvXkXlX",
"lXlXlXlXlXlXlXkXNXl V.UXz x.GXhXlXlXlXlXlXlXlXmXU s.D tXvXkXlXlXlXlXlXlXkXxXMX:.s :XmXjXlXgXGXi.  @   p xXC.<X}   o   - tXvXkXlX",
"lXlXlXlXlXlXlXjXCXx x.UXs M.FXhXlXlXlXlXlXhXDXf.5 Z.8 `.MXjXlXlXlXlXlXlXxXpXqX|.N i.ZXjXlXgXGXi.  @   u KX9 Y sX      - tXvXkXlX",
"lXlXlXlXlXlXlXhXSXt.u ,.8 7XbXkXlXlXlXlXlXjXBXb.L C   t.CXhXlXlXlXlXlXjXNXoXu n.y ,.SXhXlXgXGXi.  +     ;Xm.Q.!.  o   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXcXk.] OXMXjXlXlXlXlXlXlXlXkXNXPXfXu.lXxXlXlXlXlXlXlXlXkXvXK.^ f.lXzXlXlXgXGXi.  O X   6 m.f.=   X   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXSXLXmXkXlXlXlXlXlXlXlXlXlXjXfXlXSXlXlXlXlXlXlXlXlXlXlXlXCXLXDXzXlXlXlXgXGXi.  O   .         . .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXhXgXjXlXlXlXlXlXlXlXlXlXlXlXlXkXgXlXlXlXlXlXlXlXlXlXlXlXhXgXhXlXlXlXlXgXGXi.  O     . O O .   .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXgXGXi.  O               .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXhXgXjXlXlXlXlXlXlXlXlXlXlXlXhXgXjXlXlXlXlXlXlXlXlXlXlXlXjXgXhXlXlXlXlXgXGXi.  O     O + + X   .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXlXSXLXmXkXlXlXlXlXlXlXlXlXlXzXSXLXBXkXlXlXlXlXlXlXlXlXlXkXVXLXAXlXlXlXlXgXGXi.  O             . .   - tXvXkXlX",
"lXlXlXlXlXlXlXlXlXcXl.[ +XMXjXlXlXlXlXlXlXlXlXlXv./ ~.mXkXlXlXlXlXlXlXlXkXbXW./ n.vXlXlXlXgXGXi.  +     ,.Y.Q.D   o   - tXvXkXlX",
"lXlXlXlXlXlXlXhXSXy.i <.9 7XbXkXlXlXlXlXlXhXZXP.n c.: &XMXjXlXlXlXlXlXkXmX,Xk b.9 M.DXhXlXgXGXi.  +   + qXu.] i   X   - tXvXkXlX",
"lXlXlXlXlXlXlXjXCXc x.UXs M.FXhXlXlXlXlXlXlXzXpX0Xa.M eXvXkXlXlXlXlXlXlXzXdXeXL.z [.BXjXlXgXGXi.  +   ; uXT.Z.,   X   - tXvXkXlX",
"lXlXlXlXlXlXlXkXNXl V.UXz x.GXhXlXlXlXlXlXlXjXmXaX@.b *XnXjXlXlXlXlXlXlXkXxXmXy.h L.BXjXlXgXGXi.  +   O Y 0 Q.T.  +   - tXvXkXlX",
"lXlXlXlXlXlXlXhXFX+.B T.: %XMXjXlXlXlXlXlXhXZXm._ 2X% n.SXhXlXlXlXlXlXjXNX.XG 2Xz ] GXhXlXgXGXi.  +   , !.z W.F.  +   - tXvXkXlX",
"lXlXlXlXlXlXlXkXcXuX} k C.NXjXlXlXlXlXlXlXkXvX7X_ g 5.kXzXlXlXlXlXlXlXkXzXgX<.g ] qXcXkXlXgXGXi.  O .   ;.2XP.,   X   - tXvXkXlX",
"lXlXlXlXlXlXlXlXkXcXZXCXVXkXlXlXlXlXlXlXlXlXkXbXSXVXZXxXlXlXlXlXlXlXlXlXlXxXSXVXZXvXkXlXlXgXGXi.  O             . .   ; tXvXkXlX",
"lXlXlXlXlXlXlXlXlXkXhXjXjXlXlXlXlXlXlXkXkXkXkXjXhXhXgXkXkXkXkXlXlXkXkXkXkXkXhXhXhXjXkXkXkXfXGXi.  $ O O @ @ @ + o +   & yXcXkXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXvXbXbXbXbXbXbXbXbXbXbXbXcXkXcXbXbXbXbXbXbXbXbXbXbXbXxXnX=X6                     +.nXkXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXlXlX8X5X6X5X5X5X5X5X5X5X6X4XtXcXwX4X6X5X5X5X5X5X5X5X6X4XqXkXMX5XD.D.D.D.D.D.D.F.A.!.zXxXkXlXlX",
"lXlXlXlXzXzXzXzXzXzXzXzXzXzXlXxXBXzXlX}./.).).).).).).).)._.~.;XMX$X~._.).).).).).).)._.^.oXcXjXbXSXSXSXSXSXSXSXSXDXCXlXkXlXlXlX",
"lXkXcXuXg 0 r e e e e e e e e e q.cXkXbXnXnXnXnXnXnXnXnXnXnXmXcXkXvXnXnXnXnXnXnXnXnXnXnXnXbXlXlXkXhXhXhXhXhXhXhXhXhXhXlXlXlXlXlX",
"lXkXvXtX@                         ^.CXgXkXkXkXkXkXhXgXkXkXkXkXkXlXkXkXkXkXkXhXfXhXkXkXkXkXkXlXlXlXlXlXlXlXjXhXlXlXlXlXlXlXlXlXlX",
"lXkXvXtX:   o X X . O     X X @   Z.DXhXlXlXlXlXjXMXSXzXlXlXlXlXlXlXlXlXlXkXnXHXMXkXlXlXlXlXlXlXlXlXlXlXjXmXDXzXlXlXlXlXlXlXlXlX",
"lXkXvXtX-   .     X   S J     O   F.SXhXlXlXlXjXmX&XH.gXzXlXlXlXlXlXlXlXjXMX2Xj.%XMXjXlXlXlXlXlXlXlXlXjXMX-XZ.sXxXlXlXlXlXlXlXlX",
"lXkXvXtX-   .   X   y UX:X  . O   D.SXhXlXlXkXzXkX9 o rXvXkXlXlXlXlXlXjXmX;X9 Y t .XNXjXlXlXlXlXlXlXjXmX%Xp X 1XmXjXlXlXlXlXlXlX",
"lXkXvXtX-   .   .   /.+X~.  . O   D.SXhXlXlXgXHX1.N C 6XbXkXlXlXlXlXlXkXnX>XK.UXs m.FXhXlXlXlXlXlXlXkXvX6X).s ,XmXkXlXlXlXlXlXlX",
"lXkXvXtX-   . o   #.T.J oX  X O   D.SXhXlXjXNXoXb $Xc rXvXkXlXlXlXlXlXlXjXbXUX:.Z lXzXkXlXlXlXlXlXlXlXjXVX9X0 <XmXkXlXlXlXlXlXlX",
"lXkXvXtX-   . X   #XjX6XUXT   @   D.SXhXlXhXDX:.@ B   9.ZXhXlXlXlXlXlXlXkXbX;.s eXvXkXlXlXlXlXlXlXlXlXkXbX1X8 ,XmXkXlXlXlXlXlXlX",
"lXkXvXtX-   .     9 e 6.=X*   O   D.SXhXlXlXxXqX:XL.a #XnXkXlXlXlXlXlXjXBX.X  f i V.CXhXlXlXlXlXlXlXlXkXnX4Xd 1XmXkXlXlXlXlXlXlX",
"lXkXvXtX-   .           #   . o   F.SXhXlXlXlXvXBXnXpXvXlXlXlXlXlXlXlXlXzXfXyX0X5XaXzXlXlXlXlXlXlXlXlXlXlXkXuXjXlXlXlXlXlXlXlXlX",
"lXkXvXtX, . + O O + @ O X + O $   Z.DXgXlXlXlXkXjXkXcXkXlXlXlXlXlXlXlXlXlXzXvXvXnXxXlXlXlXlXlXlXlXlXlXlXlXlXcXlXlXlXlXlXlXlXlXlX",
"lXkXvXrX                        & *XmXjXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlX",
"lXkXxXsX,.$.&.&.&.&.&.&.&.&.&.=. XMXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXzXFXHXGXGXGXGXGXGXGXGXGXGXMXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXgXgXgXgXgXgXgXgXgXgXgXgXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_4[] = {
/* columns rows colors chars-per-pixel */
"48 48 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXjXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXkXlXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXjXlXlXlXlX",
"lXlXlXkXmXmXzXxXzXzXzXzXzXzXzXzXzXzXzXzXxXzXmXnXzXBXzXxXzXzXzXzXzXzXzXzXzXzXzXzXxXzXcXNXlXlXlXlX",
"lXlXjXmX$Xb y i p s i i i i i i i i i s a t n =XcX{ w p p s i i i i i i i i i s p i t n.NXjXlXlX",
"lXlXgXGX*.                                    0.>X                                    e cXlXlXlX",
"lXlXgXFX=.  #   d T   X X X X X X o   T 9 .   q.;X  +   e | 4   o X X X X . O Q r     p zXlXlXlX",
"lXlXgXFX=.  O   z.2X            o   C UXI     q.;X    $ Q.'. .  o       X   s pXo.    i xXlXlXlX",
"lXlXgXFX*.  O   2 T.X         .   > A.B.T     q.;X    x =X6.e.  X         O   5.@.    i zXlXlXlX",
"lXlXgXFX=.  +   9 OX.         X   S .XtXN.    q.;X    7 [.1.R.  X         O   j.>.    i xXlXlXlX",
"lXlXgXFX=.  +   - ' .   . . . . . .   T j     q.;X  O   Z d.7   X . . . . o   D v     p zXlXlXlX",
"lXlXgXGX#.  X                             o   7.-X                                .   q xXlXlXlX",
"lXlXjXNX(.2 % & & - & & & & & & & & & = = $ 3 {.jXV O * = ; * & & & & # # # # % % $ X 5.NXjXlXlX",
"lXlXlXkXmXpX7X9X9X9X9X9X9X9X9X9X9X9X9X9X9X7XaXnXcXlX7X9X9X9X9X9X9X9X8XaXfXdXfXfXfXdXjXSXlXlXlXlX",
"lXlXlXlXjXxXbXbXvXcXbXbXbXbXbXbXbXbXbXcXvXbXxXkXkXlXbXbXvXcXbXbXbXvXVXD.U W W Q W E R !.mXjXlXlX",
"lXlXlXlXlXkXkXhXnXmXhXkXkXkXkXkXkXkXjXnXxXjXkXlXlXlXkXjXvXBXjXkXjXcXeX#               a bXkXlXlX",
"lXlXlXlXlXlXkXMX:X=XMXkXlXlXlXlXlXkXbX:XyXxXlXlXlXlXkXvX7X{.cXlXkXbX8X& . X O V , X   u zXlXlXlX",
"lXlXlXlXlXjXNX.XI P _.BXjXlXlXlXjXBX%Xo W.ZXhXlXlXlXxXsX*.Q d.SXgXbX9X&     y. X4.    i xXlXlXlX",
"lXlXlXlXlXgXJX>.I./.@.JXgXlXlXlXlXjX>._ ~.ZXhXlXlXlXlXlXjX[ j.SXgXbX9X*   ; =Xd.a.    i zXlXlXlX",
"lXlXlXlXlXhXFXg.:.5.r.GXhXlXlXjXVX/.c j &.SXhXlXlXkXcXtXZ.,._ ZXgXbX9X&   + +X` oX%   i zXlXlXlX",
"lXlXlXlXlXkXxXfX<.-.aXxXkXlXlXlXzXaXwXa.Q.BXjXlXlXlXlXkXy...[.mXhXbX9X&     D P.I     i zXlXlXlX",
"lXlXlXlXlXlXlXxXAXAXxXkXlXlXlXlXlXxXnXZXMXkXlXlXlXlXlXzXAXZXMXkXkXbX9X&   X       o   i zXlXlXlX",
"lXlXlXlXlXlXlXkXhXhXkXlXlXlXlXlXlXlXkXjXkXlXlXlXlXlXlXlXhXhXjXlXkXbX9X&   . X o X X   i zXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXkXbX9X&   .       X   i zXlXlXlX",
"lXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXlXlXkXlXlXkXbX9X&   . . . . X   i zXlXlXlX",
"lXlXlXlXlXlXlXjXxXcXjXlXlXlXlXlXlXkXxXvXjXlXlXlXlXlXlXkXzXbXkXlXkXbX9X&   .       X   i zXlXlXlX",
"lXlXlXlXlXlXkXmXaXiXmXkXlXlXlXlXkXbXpXwXMXkXlXlXlXlXkXcXhX8XMXkXkXbX9X&     % y 1     i zXlXlXlX",
"lXlXlXlXlXkXnX,XE Y *XmXjXlXlXkXbX7X .! ).VXjXlXlXlXzXgX=.W V.CXgXbX9X&     K.Y.P     i zXlXlXlX",
"lXlXlXlXlXgXHX5.M.H.=.JXgXlXlXlXzXfX-XI Y.ZXhXlXlXlXlXjX6X{ s.DXgXbX9X&     K.m.A     i zXlXlXlX",
"lXlXlXlXlXhXGXw.p.z.2.HXgXlXlXkXcX0X].' r.DXhXlXlXlXxXpX{.,...ZXgXbX9X&   @ Q _ XX    i zXlXlXlX",
"lXlXlXlXlXkXvXqX' ( 6XbXkXlXlXkXbX6X| ` _.NXjXlXlXlXzXfX=./ S.NXhXbX9X*     5.~.Q     p xXlXlXlX",
"lXlXlXlXlXlXkXbXbXbXbXkXlXlXlXkXjXvXvXkXMXjXkXkXlXkXjXxXmXhXNXjXjXbX7X@ X o   +   @   e zXlXlXlX",
"lXlXlXkXgXhXhXfXgXgXfXhXjXlXxXnXnXbXbXnXvXnXnXcXzXnXnXbXvXnXvXnXbXnXdXu               K MXjXlXlX",
"lXlXkXcXDXSXSXSXSXSXSXDXNXzXuX:X<X<X,X,X,X<X:XrXgX>X<X<X,X,X,X<X>X7XmX,Xv.n.n.n.n.b.M.wXvXkXlXlX",
"lXkXvXwXN.C.C.V.V.C.C.m.[.mXyX;X>X>X>X>X>X>X-XrXgX;X>X>X>X>X>X>X;X7XzXbXFXDXDXDXDXDXDXcXkXlXlXlX",
"lXjXVX{.                  '.CXvXnXnXbXvXnXnXmXcXzXnXnXnXvXbXvXnXnXvXlXkXgXhXfXfXgXgXgXkXlXlXlXlX",
"lXjXBX.X  + o +     o $   m.DXfXkXjXzXNXlXkXkXkXlXkXjXzXNXxXmXjXkXkXlXlXlXkXnXBXzXlXlXlXlXlXlXlX",
"lXjXBX X  . X   d ;X7     C.SXhXkXvXiXM ].BXjXlXlXlXzXjX=.! }.MXjXlXlXlXkXbX4XS R.CXhXlXlXlXlXlX",
"lXjXBX X  . .   f.1Xe     V.SXhXhXZXk.s /.ZXhXlXlXkXvX0X|.e.*.JXgXlXlXlXkXxXrX^ c.FXhXlXlXlXlXlX",
"lXjXBX X  O    .+X`.~     V.SXfXBX}.b ! y.AXhXlXlXlXjXVX-X{ pXcXkXlXlXlXlXgXIXe.l.GXhXlXlXlXlXlX",
"lXjXBX X  o   l @.-X^     C.SXfXbX<XB.H t.ZXjXlXlXkXxXsXp Z Y.mXjXlXlXlXlXhXDXw.m.FXhXlXlXlXlXlX",
"lXjXBX.X  + +     +   $   N.DXhXkXbXJXzXxXzXlXlXlXlXzXgXqX<X8XxXlXlXlXlXlXlXzXaXdXzXlXlXlXlXlXlX",
"lXjXVX{.                  T.ZXhXlXkXgXlXlXlXlXlXlXlXlXzXbXmXbXkXlXlXlXlXlXlXlXxXxXlXlXlXlXlXlXlX",
"lXkXnX3X$.=.=.*.*.=.-.@.v.zXlXlXlXlXlXkXlXlXlXlXlXlXlXlXkXkXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXkXcXGXFXFXFXFXFXFXGXAXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXkXgXgXgXgXgXgXgXgXhXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_5[] = {
/* columns rows colors chars-per-pixel */
"44 44 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXkXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXjXlXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXhXlXlXlXlX",
"lXlXlXkXvXAXCXZXZXZXZXZXZXZXZXZXZXZXZXCXAXMXlXZXZXZXZXZXZXZXZXZXZXZXZXZXZXCXZXCXlXlXlXlX",
"lXlXkXvX9X' F K I L J J J J J J J L I J K '.NX7.A L I P J J J J J J J L I L A l.nXkXlXlX",
"lXlXgXFXg.                                T 7X                                $ yXcXkXlX",
"lXlXgXFXs.  # X  .b   + o o o +   i ...   W 2X  O   ^ / o o o o o O   x X..   > eXvXkXlX",
"lXlXgXFXd.  . @ `.3.  O       X   C.@X    W 3X    F &XA.:   .     X    .&X.   : rXvXkXlX",
"lXlXgXFXd.  $   _ 1.  O     o   { {.K.<   W 3X    <.M.l.N   X         O H.@   : eXvXkXlX",
"lXlXgXFXf.  #   } =.  O     X   N e.+X7   Q 3X    p S.C.0   .     .   ; Z.+   > rXvXkXlX",
"lXlXgXGXu.  # . % & . o o o X O     + X   I <X  +   2 >   O o o o o o O - O   & wXvXkXlX",
"lXlXhXCXI.                                =.dX:                               s hXzXkXlX",
"lXlXlXlXcX}.P.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.Y.T.U.W.sXMX:XL.Y.Y.Y.Y.Y.Y.U.(.}.{.{.{.{.].uXvXkXlXlX",
"lXlXlXlXkXBXAXZXVXCXAXAXAXAXAXAXAXZXVXAXZXxXjXmXAXZXVXCXAXZXCXJX'.:.3.4.5.3.:.Q.bXkXlXlX",
"lXlXlXlXlXjXhXhXCXxXgXhXhXhXhXhXgXlXMXgXhXkXlXjXhXjXVXnXgXgXlXyX=             - pXcXkXlX",
"lXlXlXlXlXlXzXkXK.3XnXkXlXlXlXkXvXwX_.cXlXlXlXlXzXjXR.oXvXjXvXwX: X   k P #   : wXvXkXlX",
"lXlXlXlXlXhXAXs.}  .dXzXlXlXlXhXGX&.m NXkXlXlXkXmX;X;.T wXcXcXrX>   0 {.W.e   , rXvXkXlX",
"lXlXlXlXlXhXZX) tXX.-XMXkXlXjXZXU.T O.pXxXlXlXlXkXcX=XY 7XvXcXeX,   Q Q.y.E   , eXvXkXlX",
"lXlXlXlXlXhXZXM.R $.kXlXlXlXjXBXY.O.k 5XbXkXlXjXNXoX@.R =XnXxXeX>   w D.J.G   , eXvXkXlX",
"lXlXlXlXlXlXlXvXXXuXbXkXlXlXlXjXBXVX0XcXlXlXlXlXlXxXoX1XnXjXvXeX:     0 g     : eXvXkXlX",
"lXlXlXlXlXlXlXkXBXcXkXlXlXlXlXlXjXhXvXkXlXlXlXlXlXlXBXnXkXkXvXeX:   o     o   : eXvXkXlX",
"lXlXlXlXlXlXlXlXjXkXlXlXlXlXlXlXlXlXkXlXlXlXlXlXlXlXjXkXlXkXvXeX:   . . X .   : eXvXkXlX",
"lXlXlXlXlXlXlXlXjXkXlXlXlXlXlXlXlXjXkXlXlXlXlXlXlXlXkXkXlXkXvXeX:   . X X .   : eXvXkXlX",
"lXlXlXlXlXlXlXkXBXcXkXlXlXlXlXlXlXBXvXkXlXlXlXlXlXlXNXnXkXkXvXeX:   .         : eXvXkXlX",
"lXlXlXlXlXlXlXvXXXuXvXkXlXlXlXlXlX.XwXvXkXlXlXlXlXxX@X4XbXjXvXeX:   X h B #   : eXvXkXlX",
"lXlXlXlXlXhXZXN.E %.kXlXlXlXjXBX].[ ..lXlXlXlXkXmX=XO./ rXcXcXeX>   a 2X2.+   : eXvXkXlX",
"lXlXlXlXlXhXZX) tXX.-XMXkXlXlXjXmX/.^ kXzXlXlXlXkXbX*XT qXcXcXeX>   y 6.s.y   > eXvXkXlX",
"lXlXlXlXlXhXAXa.{ | dXzXlXlXjXBX^.-.I qXvXkXlXjXMXOX<.K $XmXxXrX>   e 2.W.m   , rXvXkXlX",
"lXlXlXlXlXlXzXkXJ.3XnXkXlXlXkXxXiXG.&XbXjXlXlXkXlXgXI.|.vXhXvXwX:   O E C   X : wXvXkXlX",
"lXlXlXlXhXhXhXhXCXxXgXjXkXzXbXvXnXJXCXcXbXcXlXvXvXbXHXAXcXvXnXpX:             : pXcXkXlX",
"lXlXlXzXZXAXAXZXVXCXAXVXzXfX9X0X9X7X8X0X8XyXjX9X0X0X7X8X0X9XqXnXT...#.%.%.#...T.nXkXlXlX",
"lXlXzXgXW.U.Y.Y.Y.T.I./.zXpX&X-X=X=X=X-X&X5XgX=X=X=X=X=X-X*X<XlXVXGXFXFXDXFXGXVXkXlXlXlX",
"lXkXvXeXo               s.DXcXnXbXbXNXbXnXvXzXnXnXbXBXMXbXnXbXlXjXgXgXgXlXgXgXjXlXlXlXlX",
"lXkXvXrX,   O X o ; @   ..FXfXkXkXzXyXkXkXkXlXkXjXbX8XaXcXjXkXlXlXlXzXlXtXzXlXlXlXlXlXlX",
"lXkXvXeX:   O   V.J.    $.FXgXgXHXi.A NXkXlXlXjXNXOX` o.iXxXkXlXlXjXBXk.F cXlXlXlXlXlXlX",
"lXkXvXeX:     Z ~.u.    @.FXfXMX=X) #.lXlXlXlXlXzXdX5XX.pXxXlXlXlXlXcX2X` gXzXlXlXlXlXlX",
"lXkXvXeX:     r.oX:X*   #.FXsXAXx.H d 2XnXkXlXkXvXeXz g.bXkXlXlXlXkXcXpXE gXzXlXlXlXlXlX",
"lXkXvXrX,   +   q I o   @.FXgXkXxXtXT.jXzXlXlXkXmX=Xq.v.tXcXkXlXlXlXzXdXW.jXzXlXlXlXlXlX",
"lXkXvXeXX               #.GXgXlXlXcXCXzXlXlXlXlXkXnXHXSXxXlXlXlXlXlXlXzXVXlXlXlXlXlXlXlX",
"lXkXcXiXQ G K J K I H E =XnXkXlXlXkXjXlXlXlXlXlXlXkXgXhXlXlXlXlXlXlXlXlXjXlXlXlXlXlXlXlX",
"lXlXlXzXCXZXZXZXZXZXCXAXnXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXhXhXhXhXhXhXhXhXkXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_6[] = {
/* columns rows colors chars-per-pixel */
"32 32 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"lXlXjXjXjXjXjXjXjXjXjXjXjXjXjXjXkXhXjXjXjXjXjXjXjXjXjXjXjXhXlXlX",
"lXkXmXBXMXNXNXMXMXMXMXMXNXNXNXNXvXVXMXNXNXMXMXMXMXMXNXNXMXVXzXlX",
"jXNX~.c M v b m m m m m n n h v.0XS n v v m m m m m b b l %.xXlX",
"gXGXo.    X               X   A K.                    .   o eXvX",
"gXDX*.  o S.S   + X @   w.9.  R U.  5 R.*.  + o +   %.y.  2 eXvX",
"gXFX&.    %.T   o X   f =Xg.  U Y.  S ~.u.X     .   g y.  < eXvX",
"gXFX$.    J c   + +   1 [ &.  I L.  - 3.[   + O +   q (   , wXvX",
"gXFX;.                        P !.                        # uXcX",
"kXvX6Xa.u.p.p.i.i.i.i.p.s.s.e.#XkXx.y.s.a.i.u.a.b.v.b.m.k.{.bXkX",
"lXkXvXFXDXGXDXFXFXFXFXFXDXFXGXmXzXDXFXHXFXDXHXmX6.| o.X.[ h.cXlX",
"lXlXkXfXzXiXlXgXgXgXgXgXlXdXgXjXlXgXjXuXhXdXMX^.          . rXvX",
"lXlXjXMX&XO.L.NXjXlXhXGXh.d.DXhXkXxXsX3.l.mXNX`.  # c.6.  < eXvX",
"lXlXhXFXl.x.6.nXjXjXmX:XB 5.VXhXlXzXlXG.O.bXBX'.  f /.h.$ = rXvX",
"lXlXkXnX<X$.Q.NXjXkXvX8Xg.a.mXjXkXcXyX6.l.xXVX`.  @ 3.<.  ; eXvX",
"lXlXlXkXbXvXnXlXlXlXkXbXAXMXlXlXlXkXcXzXnXjXVX`.          : eXvX",
"lXlXlXlXkXkXkXlXlXlXlXkXhXjXlXlXlXlXkXlXkXhXCX`.  X . X   ; eXvX",
"lXlXlXlXkXkXkXlXlXlXlXkXlXkXlXlXlXlXlXlXkXhXVX`.  X       ; eXvX",
"lXlXlXkXbXvXnXlXlXlXkXxXxXbXlXlXlXlXxXxXbXjXVX`.      #   ; eXvX",
"lXlXkXnX1X%.!.NXjXkXvXeX,.U.BXjXkXxXsX7.V.nXBX`.  * A.R   > eXvX",
"lXlXhXFXz.x.6.nXjXkXzXkXz.2.ZXhXlXlXlXG.@.nXBX`.  1 s.5.  : eXvX",
"lXlXjXMX%Xo.K.NXjXkXvX6X=.z.MXjXkXcXtX3.y.xXBX`.  * 4.q.  , eXvX",
"lXlXhXfXzXiXlXgXjXxXvXbXdXmXvXxXzXcXnXfXbXcXAX_.          O rXvX",
"lXzXDXFXDXHXDXFXmXaXqXwXtXwXqXuXfXqXwXtXwXqXuXiX#.T W ! I r.cXkX",
"xXsXg.y.i.a.a.t.,XdX<X3X<X1X1X0XaX1X3X<X1X2X6XxXSXAXZXZXSXZXlXlX",
"bXwX            ^ GXxXcXZXCXvXvXxXvXmXZXZXvXvXkXhXgXbXvXgXhXlXlX",
"vXeX< o   @.~   ~ AXsXSXL.B.CXhXkXxXyXq.K.nXjXlXjXBXJ.M.CXjXlXlX",
"vXeX>   t %X*.  / ZXzXqXJ 9.ZXhXlXzXkXG.s.VXjXlXkXBX^.4.AXhXlXlX",
"vXeX1   b J.q.  / ZXvX;X@.1.MXjXkXcXiXL J.MXkXlXkXmX1Xg.CXjXlXlX",
"vXwXo           P DXfXnXNXgXzXlXlXzXfX3X8XzXlXlXlXzXhXsXzXlXlXlX",
"cXuXG c N M m l D.BXjXkXjXzXlXlXlXlXzXnXbXlXlXlXlXlXzXxXlXlXlXlX",
"lXzXMXMXMXMXMXNXNXkXlXlXlXlXlXlXlXlXlXkXkXlXlXlXlXlXlXlXlXlXlXlX",
"lXlXjXjXjXjXjXjXjXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlXlX"
};

/* XPM */
static const char *const xpm_icon_7[] = {
/* columns rows colors chars-per-pixel */
"24 24 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"zXxXiXsXaXpXpXpXpXdXpXxXbXaXsXsXpXpXpXpXdXiXlXxX",
"VX$.: 1 4 9 8 8 9 , * 8.C.- < 1 9 8 8 8 , > U lX",
"NXv   I 0         !   P ;.  U b         ~ o ; iX",
"NXF   $.U   $   F 3X& W 4.  ^.t.  O +   w.y 3 sX",
"NXb   e 9       1 _   K :.  P Z         a O = iX",
"VX+.& 1 , 5 3 5 > % O 6.B.$ ; - 4 3 r s t 8 Q kX",
"zXxXuXdXaXiXpXpXpXfXpXxXvXpXfXsXuXdXQ.l.b.j.].nX",
"lXkXmXsXxXvXcXxXnXkXzXlXkXvXaXkXbXgX3       5 dX",
"kXvXwX7.I.MXgXxXeX#.tXcXjXnXZ.z.ZXuX; y K.q 2 aX",
"kXnX4X:.V.NXfXBX!.H 3XnXjXnXV.7.CXpX* l ^.z > dX",
"lXkXvX;XiXcXlXlXzX0XdXzXkXxX:X8XbXiX4   i   7 pX",
"lXlXkXbXxXlXlXlXkXxXzXlXlXlXbXxXxXpX4       9 pX",
"lXlXlXNXvXkXlXkXvXNXlXlXlXlXMXbXxXpX4       9 pX",
"lXlXcX`.7XvXjXvX7X`.lXlXkXvX X-XMXiX< = Y   7 pX",
"kXmX,X*.b.NXgXvX3X| 6XbXjXmXZ.5.AXiX- a I.6 2 sX",
"kXzXuXu./.nXhXnX-Xq.rXvXkXbXD.N.BXuX: - 6.0 , pX",
"zXMXVXVXZXnXlXlXlXcXcXkXlXzXlXvXxXgXy       s hX",
"dX&X%X*X#X4XhX<X1X,X,XqXrX,X1X<X,XdX6X XoX X5XcX",
"$XO       = 2XbXkXmXkXlXlXlXzXbXkXkXbXBXSXVXbXkX",
"$X@   / F   &XBXgXp.iXcXkXvXJ.P.NXjXkXkXf.7XcXkX",
"&XO %  X-.  =XHXE.n 5XnXhXNXl.m.CXjXjXVXg.=XMXkX",
"#X    0 7   $XBXyX}.yXcXkXvXK.OXbXkXkXbX<XuXcXlX",
"<XS B v l Q tXcXxXBXxXkXlXkXCXmXkXlXlXkXbXxXlXlX",
"zXNXNXVXBXVXcXkXlXjXlXlXlXlXhXjXlXlXlXlXkXkXlXlX"
};

/* XPM */
static const char *const xpm_icon_8[] = {
/* columns rows colors chars-per-pixel */
"16 16 256 2 ",
"   c black",
".  c #010101",
"X  c #020202",
"o  c gray1",
"O  c #040404",
"+  c gray2",
"@  c #060606",
"#  c #070707",
"$  c gray3",
"%  c #090909",
"&  c gray4",
"*  c #0B0B0B",
"=  c #0C0C0C",
"-  c gray5",
";  c #0E0E0E",
":  c gray6",
">  c #101010",
",  c #111111",
"<  c gray7",
"1  c #131313",
"2  c gray8",
"3  c #151515",
"4  c #161616",
"5  c gray9",
"6  c #181818",
"7  c #191919",
"8  c gray10",
"9  c #1B1B1B",
"0  c gray11",
"q  c #1D1D1D",
"w  c #1E1E1E",
"e  c gray12",
"r  c #202020",
"t  c gray13",
"y  c #222222",
"u  c #232323",
"i  c gray14",
"p  c #252525",
"a  c gray15",
"s  c #272727",
"d  c #282828",
"f  c gray16",
"g  c #2A2A2A",
"h  c gray17",
"j  c #2C2C2C",
"k  c #2D2D2D",
"l  c gray18",
"z  c #2F2F2F",
"x  c gray19",
"c  c #313131",
"v  c #323232",
"b  c gray20",
"n  c #343434",
"m  c #353535",
"M  c gray21",
"N  c #373737",
"B  c gray22",
"V  c #393939",
"C  c #3A3A3A",
"Z  c gray23",
"A  c #3C3C3C",
"S  c gray24",
"D  c #3E3E3E",
"F  c #3F3F3F",
"G  c gray25",
"H  c #414141",
"J  c gray26",
"K  c #434343",
"L  c #444444",
"P  c gray27",
"I  c #464646",
"U  c gray28",
"Y  c #484848",
"T  c #494949",
"R  c gray29",
"E  c #4B4B4B",
"W  c #4C4C4C",
"Q  c gray30",
"!  c #4E4E4E",
"~  c gray31",
"^  c #505050",
"/  c #515151",
"(  c gray32",
")  c #535353",
"_  c gray33",
"`  c #555555",
"'  c #565656",
"]  c gray34",
"[  c #585858",
"{  c gray35",
"}  c #5A5A5A",
"|  c #5B5B5B",
" . c gray36",
".. c #5D5D5D",
"X. c gray37",
"o. c #5F5F5F",
"O. c #606060",
"+. c gray38",
"@. c #626262",
"#. c gray39",
"$. c #646464",
"%. c #656565",
"&. c gray40",
"*. c #676767",
"=. c #686868",
"-. c DimGray",
";. c #6A6A6A",
":. c gray42",
">. c #6C6C6C",
",. c #6D6D6D",
"<. c gray43",
"1. c #6F6F6F",
"2. c gray44",
"3. c #717171",
"4. c #727272",
"5. c gray45",
"6. c #747474",
"7. c gray46",
"8. c #767676",
"9. c #777777",
"0. c gray47",
"q. c #797979",
"w. c gray48",
"e. c #7B7B7B",
"r. c #7C7C7C",
"t. c gray49",
"y. c #7E7E7E",
"u. c gray50",
"i. c #808080",
"p. c #818181",
"a. c gray51",
"s. c #838383",
"d. c #848484",
"f. c gray52",
"g. c #868686",
"h. c gray53",
"j. c #888888",
"k. c #898989",
"l. c gray54",
"z. c #8B8B8B",
"x. c gray55",
"c. c #8D8D8D",
"v. c #8E8E8E",
"b. c gray56",
"n. c #909090",
"m. c gray57",
"M. c #929292",
"N. c #939393",
"B. c gray58",
"V. c #959595",
"C. c gray59",
"Z. c #979797",
"A. c #989898",
"S. c gray60",
"D. c #9A9A9A",
"F. c #9B9B9B",
"G. c gray61",
"H. c #9D9D9D",
"J. c gray62",
"K. c #9F9F9F",
"L. c #A0A0A0",
"P. c gray63",
"I. c #A2A2A2",
"U. c gray64",
"Y. c #A4A4A4",
"T. c #A5A5A5",
"R. c gray65",
"E. c #A7A7A7",
"W. c gray66",
"Q. c #A9A9A9",
"!. c #AAAAAA",
"~. c gray67",
"^. c #ACACAC",
"/. c gray68",
"(. c #AEAEAE",
"). c #AFAFAF",
"_. c gray69",
"`. c #B1B1B1",
"'. c #B2B2B2",
"]. c gray70",
"[. c #B4B4B4",
"{. c gray71",
"}. c #B6B6B6",
"|. c #B7B7B7",
" X c gray72",
".X c #B9B9B9",
"XX c gray73",
"oX c #BBBBBB",
"OX c #BCBCBC",
"+X c gray74",
"@X c gray",
"#X c gray75",
"$X c #C0C0C0",
"%X c #C1C1C1",
"&X c gray76",
"*X c #C3C3C3",
"=X c gray77",
"-X c #C5C5C5",
";X c #C6C6C6",
":X c gray78",
">X c #C8C8C8",
",X c gray79",
"<X c #CACACA",
"1X c #CBCBCB",
"2X c gray80",
"3X c #CDCDCD",
"4X c #CECECE",
"5X c gray81",
"6X c #D0D0D0",
"7X c gray82",
"8X c #D2D2D2",
"9X c LightGray",
"0X c gray83",
"qX c #D5D5D5",
"wX c gray84",
"eX c #D7D7D7",
"rX c #D8D8D8",
"tX c gray85",
"yX c #DADADA",
"uX c gray86",
"iX c gainsboro",
"pX c #DDDDDD",
"aX c gray87",
"sX c #DFDFDF",
"dX c gray88",
"fX c #E1E1E1",
"gX c #E2E2E2",
"hX c gray89",
"jX c #E4E4E4",
"kX c gray90",
"lX c #E6E6E6",
"zX c #E7E7E7",
"xX c gray91",
"cX c #E9E9E9",
"vX c #EAEAEA",
"bX c gray92",
"nX c #ECECEC",
"mX c gray93",
"MX c #EEEEEE",
"NX c #EFEFEF",
"BX c gray94",
"VX c #F1F1F1",
"CX c gray95",
"ZX c #F3F3F3",
"AX c #F4F4F4",
"SX c gray96",
"DX c #F6F6F6",
"FX c gray97",
"GX c #F8F8F8",
"HX c #F9F9F9",
"JX c gray98",
"KX c #FBFBFB",
"LX c gray99",
"PX c #FDFDFD",
"IX c #FEFEFE",
"UX c white",
/* pixels */
"zXxXfXhXjXkXgXxXvXgXhXjXjXfXzXxX",
"NX..t g i i q ' 2.0 g i a d A pX",
"BXa d p   - ;.g m ) J     J : 7X",
"BXN   %   O 7 v R - 4   # 8 t eX",
"cX;X'.]._._.^.*X3X!.'.~.;.Q e.lX",
"kXVX-XtXFXMX=XnXVX6XpX0X& M 4 qX",
"kXbXx.].VX6X0.fXNXU._.,X1 8.0 9X",
"lXlXlXzXlXzXvXkXlXgXMX;X.   2 qX",
"lXlXzXzXlXkXkXzXlXhXNX-XO   1 wX",
"kXvXx.].VXrXz.hXBXE.[.1X2 ;.6 0X",
"lXAX-XtXNXpX'.kXnX$X4X<X  t - qX",
"gX{.`.`.eXrXhXtXtXaXaXrXP.m.E.kX",
"wX% > X A.ZX@XjXvX<X6XbXZXwXVXzX",
"eX  o.d x.kX2.gXCXK.'.NXjXL.iXxX",
"rXm p r /.VXsXkXxXyXdXzXlXkXkXlX",
"lXjXgXjXcXlXxXlXkXcXxXlXlXzXlXlX"
};

const char *const *const xpm_icons[] = {
    xpm_icon_0,
    xpm_icon_1,
    xpm_icon_2,
    xpm_icon_3,
    xpm_icon_4,
    xpm_icon_5,
    xpm_icon_6,
    xpm_icon_7,
    xpm_icon_8,
};
const int n_xpm_icons = 9;
